@@ -1,23 +1,22 @@
 #==============================================================================
 # Main Tablelist_tile package module.
 #
-# Copyright (c) 2000-2011  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
+# Copyright (c) 2000-2025  Csaba Nemethi (E-mail: csaba.nemethi@t-online.de)
 #==============================================================================
 
-package require Tcl 8.4
-package require Tk  8.4
+package require -exact tablelist::common 7.6
+
 if {$::tk_version < 8.5 || [regexp {^8\.5a[1-5]$} $::tk_patchLevel]} {
-    package require tile 0.6
+    package require tile 0.6[tablelist::-]
 }
-package require -exact tablelist::common 5.5
 
-package provide tablelist_tile $::tablelist::version
-package provide Tablelist_tile $::tablelist::version
+package provide tablelist_tile $tablelist::version
+package provide Tablelist_tile $tablelist::version
 
-::tablelist::useTile 1
-::tablelist::createBindings
+tablelist::useTile 1
+tablelist::createBindings
 
-namespace eval ::tablelist {
+namespace eval tablelist {
     #
     # Commands related to tile themes:
     #
